pub struct MarketCloseCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for MarketClose via CPI.
Accounts:
[writable, signer]authority[writable]market[]mint_a[]mint_b[writable]market_a[writable]market_b[]system_program[]ata_program[]token_program_a[]token_program_b
Implementations
Sourceimpl<'a, 'b> MarketCloseCpiBuilder<'a, 'b>
impl<'a, 'b> MarketCloseCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
The market authority
Sourcepub fn market(&mut self, market: &'b AccountInfo<'a>) -> &mut Self
pub fn market(&mut self, market: &'b AccountInfo<'a>) -> &mut Self
The market
Sourcepub fn mint_a(&mut self, mint_a: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_a(&mut self, mint_a: &'b AccountInfo<'a>) -> &mut Self
The token a mint
Sourcepub fn mint_b(&mut self, mint_b: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_b(&mut self, mint_b: &'b AccountInfo<'a>) -> &mut Self
The token b mint
Sourcepub fn market_a(&mut self, market_a: &'b AccountInfo<'a>) -> &mut Self
pub fn market_a(&mut self, market_a: &'b AccountInfo<'a>) -> &mut Self
The market token account for token a
Sourcepub fn market_b(&mut self, market_b: &'b AccountInfo<'a>) -> &mut Self
pub fn market_b(&mut self, market_b: &'b AccountInfo<'a>) -> &mut Self
The market token account for token b
Sourcepub fn system_program(
&mut self,
system_program: &'b AccountInfo<'a>,
) -> &mut Self
pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self
The system program
Sourcepub fn ata_program(&mut self, ata_program: &'b AccountInfo<'a>) -> &mut Self
pub fn ata_program(&mut self, ata_program: &'b AccountInfo<'a>) -> &mut Self
The ata program
Sourcepub fn token_program_a(
&mut self,
token_program_a: &'b AccountInfo<'a>,
) -> &mut Self
pub fn token_program_a( &mut self, token_program_a: &'b AccountInfo<'a>, ) -> &mut Self
The token program for token a
Sourcepub fn token_program_b(
&mut self,
token_program_b: &'b AccountInfo<'a>,
) -> &mut Self
pub fn token_program_b( &mut self, token_program_b: &'b AccountInfo<'a>, ) -> &mut Self
The token program for token b
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the
account is writable or not, and a bool indicating whether the account is a signer or
not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult