pub struct MarketDepositInstructionArgs {
pub amount_a: u64,
pub amount_b: u64,
}Fields
amount_a: u64amount_b: u64Trait Implementations
Sourceimpl BorshDeserialize for MarketDepositInstructionArgs
impl BorshDeserialize for MarketDepositInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MarketDepositInstructionArgs
impl Clone for MarketDepositInstructionArgs
Sourcefn clone(&self) -> MarketDepositInstructionArgs
fn clone(&self) -> MarketDepositInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarketDepositInstructionArgs
impl Debug for MarketDepositInstructionArgs
Sourceimpl PartialEq for MarketDepositInstructionArgs
impl PartialEq for MarketDepositInstructionArgs
Sourcefn eq(&self, other: &MarketDepositInstructionArgs) -> bool
fn eq(&self, other: &MarketDepositInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MarketDepositInstructionArgs
impl StructuralPartialEq for MarketDepositInstructionArgs