pub struct MarketInitializeInstructionArgs {
pub market_id: u32,
}Fields
market_id: u32Trait Implementations
Sourceimpl BorshDeserialize for MarketInitializeInstructionArgs
impl BorshDeserialize for MarketInitializeInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MarketInitializeInstructionArgs
impl Clone for MarketInitializeInstructionArgs
Sourcefn clone(&self) -> MarketInitializeInstructionArgs
fn clone(&self) -> MarketInitializeInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for MarketInitializeInstructionArgs
impl PartialEq for MarketInitializeInstructionArgs
Sourcefn eq(&self, other: &MarketInitializeInstructionArgs) -> bool
fn eq(&self, other: &MarketInitializeInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MarketInitializeInstructionArgs
impl StructuralPartialEq for MarketInitializeInstructionArgs