pub struct MarketUpdateInstructionArgs {
pub update: MarketUpdateType,
}Fields
update: MarketUpdateTypeTrait Implementations
Sourceimpl BorshDeserialize for MarketUpdateInstructionArgs
impl BorshDeserialize for MarketUpdateInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MarketUpdateInstructionArgs
impl Clone for MarketUpdateInstructionArgs
Sourcefn clone(&self) -> MarketUpdateInstructionArgs
fn clone(&self) -> MarketUpdateInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarketUpdateInstructionArgs
impl Debug for MarketUpdateInstructionArgs
impl Eq for MarketUpdateInstructionArgs
impl StructuralPartialEq for MarketUpdateInstructionArgs