pub struct MarketWithdrawInstructionArgs {
pub amount_a: u64,
pub amount_b: u64,
}Fields
amount_a: u64amount_b: u64Trait Implementations
Sourceimpl BorshDeserialize for MarketWithdrawInstructionArgs
impl BorshDeserialize for MarketWithdrawInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MarketWithdrawInstructionArgs
impl Clone for MarketWithdrawInstructionArgs
Sourcefn clone(&self) -> MarketWithdrawInstructionArgs
fn clone(&self) -> MarketWithdrawInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for MarketWithdrawInstructionArgs
impl PartialEq for MarketWithdrawInstructionArgs
Sourcefn eq(&self, other: &MarketWithdrawInstructionArgs) -> bool
fn eq(&self, other: &MarketWithdrawInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MarketWithdrawInstructionArgs
impl StructuralPartialEq for MarketWithdrawInstructionArgs