pub struct OraclePayload {
pub data: OracleData,
pub skew: SkewMode,
}Fields
data: OracleDataskew: SkewModeTrait Implementations
Sourceimpl BorshDeserialize for OraclePayload
impl BorshDeserialize for OraclePayload
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OraclePayload
impl Clone for OraclePayload
Sourcefn clone(&self) -> OraclePayload
fn clone(&self) -> OraclePayload
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OraclePayload
impl Debug for OraclePayload
Sourceimpl PartialEq for OraclePayload
impl PartialEq for OraclePayload
impl Copy for OraclePayload
impl Eq for OraclePayload
impl StructuralPartialEq for OraclePayload