pub struct OracleUpdateInstructionArgs {
pub sequence: u64,
pub valid_until: u64,
pub data: [u8; 512],
}Fields
sequence: u64valid_until: u64data: [u8; 512]Trait Implementations
Sourceimpl BorshDeserialize for OracleUpdateInstructionArgs
impl BorshDeserialize for OracleUpdateInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OracleUpdateInstructionArgs
impl Clone for OracleUpdateInstructionArgs
Sourcefn clone(&self) -> OracleUpdateInstructionArgs
fn clone(&self) -> OracleUpdateInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OracleUpdateInstructionArgs
impl Debug for OracleUpdateInstructionArgs
impl Eq for OracleUpdateInstructionArgs
impl StructuralPartialEq for OracleUpdateInstructionArgs