pub struct SwapExactInCpiBuilder<'a, 'b> { /* private fields */ }Expand description
Instruction builder for SwapExactIn via CPI.
Accounts:
[signer]authority[writable]market[]mint_a[]mint_b[writable]authority_a[writable]authority_b[writable]market_a[writable]market_b[]token_program_a[]token_program_b[]memo_program[]instructions_sysvar
Implementations
Sourceimpl<'a, 'b> SwapExactInCpiBuilder<'a, 'b>
impl<'a, 'b> SwapExactInCpiBuilder<'a, 'b>
pub fn new(program: &'b AccountInfo<'a>) -> Self
The authority
Sourcepub fn market(&mut self, market: &'b AccountInfo<'a>) -> &mut Self
pub fn market(&mut self, market: &'b AccountInfo<'a>) -> &mut Self
The market
Sourcepub fn mint_a(&mut self, mint_a: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_a(&mut self, mint_a: &'b AccountInfo<'a>) -> &mut Self
The token a mint
Sourcepub fn mint_b(&mut self, mint_b: &'b AccountInfo<'a>) -> &mut Self
pub fn mint_b(&mut self, mint_b: &'b AccountInfo<'a>) -> &mut Self
The token b mint
The authority’s token account for token a
The authority’s token account for token b
Sourcepub fn market_a(&mut self, market_a: &'b AccountInfo<'a>) -> &mut Self
pub fn market_a(&mut self, market_a: &'b AccountInfo<'a>) -> &mut Self
The treasury token account for token a
Sourcepub fn market_b(&mut self, market_b: &'b AccountInfo<'a>) -> &mut Self
pub fn market_b(&mut self, market_b: &'b AccountInfo<'a>) -> &mut Self
The market token account for token b
Sourcepub fn token_program_a(
&mut self,
token_program_a: &'b AccountInfo<'a>,
) -> &mut Self
pub fn token_program_a( &mut self, token_program_a: &'b AccountInfo<'a>, ) -> &mut Self
The token program for token a
Sourcepub fn token_program_b(
&mut self,
token_program_b: &'b AccountInfo<'a>,
) -> &mut Self
pub fn token_program_b( &mut self, token_program_b: &'b AccountInfo<'a>, ) -> &mut Self
The token program for token b
Sourcepub fn memo_program(&mut self, memo_program: &'b AccountInfo<'a>) -> &mut Self
pub fn memo_program(&mut self, memo_program: &'b AccountInfo<'a>) -> &mut Self
The memo program
Sourcepub fn instructions_sysvar(
&mut self,
instructions_sysvar: &'b AccountInfo<'a>,
) -> &mut Self
pub fn instructions_sysvar( &mut self, instructions_sysvar: &'b AccountInfo<'a>, ) -> &mut Self
The instructions sysvar
pub fn amount_in(&mut self, amount_in: u64) -> &mut Self
pub fn amount_is_token_a(&mut self, amount_is_token_a: bool) -> &mut Self
pub fn slippage_tolerance( &mut self, slippage_tolerance: SlippageTolerance, ) -> &mut Self
pub fn allow_partial_fill(&mut self, allow_partial_fill: bool) -> &mut Self
Sourcepub fn add_remaining_account(
&mut self,
account: &'b AccountInfo<'a>,
is_writable: bool,
is_signer: bool,
) -> &mut Self
pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self
Add an additional account to the instruction.
Sourcepub fn add_remaining_accounts(
&mut self,
accounts: &[(&'b AccountInfo<'a>, bool, bool)],
) -> &mut Self
pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self
Add additional accounts to the instruction.
Each account is represented by a tuple of the AccountInfo, a bool indicating whether the
account is writable or not, and a bool indicating whether the account is a signer or
not.
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult