pub struct SwapExactInInstructionArgs {
pub amount_in: u64,
pub amount_is_token_a: bool,
pub slippage_tolerance: SlippageTolerance,
pub allow_partial_fill: bool,
}Fields
amount_in: u64amount_is_token_a: boolslippage_tolerance: SlippageToleranceallow_partial_fill: boolTrait Implementations
Sourceimpl BorshDeserialize for SwapExactInInstructionArgs
impl BorshDeserialize for SwapExactInInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SwapExactInInstructionArgs
impl Clone for SwapExactInInstructionArgs
Sourcefn clone(&self) -> SwapExactInInstructionArgs
fn clone(&self) -> SwapExactInInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SwapExactInInstructionArgs
impl Debug for SwapExactInInstructionArgs
impl Eq for SwapExactInInstructionArgs
impl StructuralPartialEq for SwapExactInInstructionArgs