pub struct SwapExactOutInstructionArgs {
pub amount_out: u64,
pub amount_is_token_a: bool,
pub slippage_tolerance: SlippageTolerance,
pub allow_partial_fill: bool,
}Fields
amount_out: u64amount_is_token_a: boolslippage_tolerance: SlippageToleranceallow_partial_fill: boolTrait Implementations
Sourceimpl BorshDeserialize for SwapExactOutInstructionArgs
impl BorshDeserialize for SwapExactOutInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SwapExactOutInstructionArgs
impl Clone for SwapExactOutInstructionArgs
Sourcefn clone(&self) -> SwapExactOutInstructionArgs
fn clone(&self) -> SwapExactOutInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SwapExactOutInstructionArgs
impl Debug for SwapExactOutInstructionArgs
impl Eq for SwapExactOutInstructionArgs
impl StructuralPartialEq for SwapExactOutInstructionArgs